
import React from 'react';
import { Card, CardContent } from '@/components/ui/card';
import { Quote } from 'lucide-react';

const testimonials = [
  {
    quote: "Techbitans transformed our retail business with their POS and inventory solution. We've increased efficiency by 40%.",
    author: "Sarah Johnson",
    position: "Retail Store Owner"
  },
  {
    quote: "The e-commerce platform developed by Techbitans helped us scale our online presence and increase sales by 250%.",
    author: "Michael Chen",
    position: "E-commerce Director"
  },
  {
    quote: "Their HRM system streamlined our HR processes and saved us countless hours on administrative tasks.",
    author: "Laura Martinez",
    position: "HR Manager"
  }
];

const TestimonialSection = () => {
  return (
    <section className="py-16 bg-white">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="text-center mb-12">
          <h2 className="text-3xl font-bold text-gray-900">
            What Our Clients Say
          </h2>
          <p className="mt-4 max-w-2xl mx-auto text-xl text-gray-500">
            Businesses that have transformed with our solutions
          </p>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
          {testimonials.map((testimonial, index) => (
            <Card key={index} className="border-0 shadow-lg">
              <CardContent className="p-6">
                <Quote className="h-8 w-8 text-primary opacity-50 mb-4" />
                <p className="text-gray-600 mb-6 italic">{testimonial.quote}</p>
                <div className="flex items-center">
                  <div className="bg-blue-100 rounded-full h-10 w-10 flex items-center justify-center text-primary font-bold">
                    {testimonial.author.charAt(0)}
                  </div>
                  <div className="ml-3">
                    <p className="text-sm font-medium text-gray-900">{testimonial.author}</p>
                    <p className="text-sm text-gray-500">{testimonial.position}</p>
                  </div>
                </div>
              </CardContent>
            </Card>
          ))}
        </div>
      </div>
    </section>
  );
};

export default TestimonialSection;
